@@ -34,6 +34,7 @@
 #define __SNGREP_GROUP_H_
 
 #include "config.h"
+#include "vector.h"
 #include "sip.h"
 
 //! Shorter declaration of sip_call_group structure
@@ -45,8 +46,6 @@ typedef struct sip_call_group sip_call_group_t;
  * This structure is used for displaying more than one dialog in the
  * same call flow. Instead of displaying a call flow, we will display
  * a calls group flow.
- *
- * @fixme Remove 1024 "limitation"
  */
 struct sip_call_group {
     //! Calls array in the group
@@ -75,6 +74,17 @@ call_group_create();
 void
 call_group_destroy(sip_call_group_t *group);
 
+/**
+ * @brief Clone an existing call group
+ *
+ * Create a new call group with the same calls of the
+ * original one. Beware: The call pointers are shared between
+ * original and clone groups.
+ *
+ */
+sip_call_group_t *
+call_group_clone(sip_call_group_t *original);
+
 /**
  * @brief Add a Call to the group
  *
@@ -187,27 +197,14 @@ call_group_get_next_msg(sip_call_group_t *group, sip_msg_t *msg);
 sip_msg_t *
 call_group_get_prev_msg(sip_call_group_t *group, sip_msg_t *msg);
 
+/**
+ * @brief Find the next stream in a call group
+ *
+ * @param callgroup SIP call group structure
+ * @param msg Actual stream structure from any call of the group
+ * @return next chronological stream in the group or NULL
+ */
 rtp_stream_t *
 call_group_get_next_stream(sip_call_group_t *group, rtp_stream_t *stream);
 
-int
-timeval_is_older(struct timeval t1, struct timeval t2);
-
-/**
- * @brief Check if a message is older than other
- *
- * @todo Move this to sip.h
- *
- * @param one SIP message pointer
- * @param two SIP message pointer
- * @return 0 if the messages has the same timestamp
- * @return 1 if one is older than two
- * @return 2 if two is older than one
- */
-int
-sip_msg_is_older(sip_msg_t *one, sip_msg_t *two);
-
-int
-rtp_stream_is_older(rtp_stream_t *one, rtp_stream_t *two);
-
 #endif /* __SNGREP_GROUP_H_ */
