@@ -87,10 +87,10 @@ enum key_actions {
     ACTION_SHOW_FILTERS,
     ACTION_SHOW_COLUMNS,
     ACTION_SHOW_SETTINGS,
+    ACTION_SHOW_STATS,
     ACTION_COLUMN_MOVE_UP,
     ACTION_COLUMN_MOVE_DOWN,
     ACTION_DISP_FILTER,
-    ACTION_DISP_INVITE,
     ACTION_SAVE,
     ACTION_SELECT,
     ACTION_CONFIRM,
@@ -103,6 +103,7 @@ enum key_actions {
     ACTION_SDP_INFO,
     ACTION_COMPRESS,
     ACTION_TOGGLE_HINT,
+    ACTION_AUTOSCROLL,
     ACTION_SENTINEL
 };
 
@@ -113,24 +114,29 @@ typedef struct key_binding key_binding_t;
  * @brief Struct to hold a keybinding data
  */
 struct key_binding {
+    //! Keybinding action id
+    int id;
+    //! Keybinding action name
+    const char *name;
     //! keybindings for this action
     int keys[MAX_BINDINGS];
     //! How many keys are binded to this action
     int bindcnt;
 };
 
-/**
- * @brief Initialize default keybindings
- */
-void
-key_bindings_init();
-
 /**
  * @brief Print configured keybindigs
  */
 void
 key_bindings_dump();
 
+/**
+ * @brief Return Keybinding data for a given action
+ * @return key_binding_t structure pointer or NULL if not found
+ */
+key_binding_t *
+key_binding_data(int action);
+
 /**
  * @brief Bind a key to an action
  *
@@ -214,4 +220,13 @@ key_from_str(const char *key);
 const char *
 key_action_key_str(int action);
 
+/**
+ * @brief Return key value for a given action
+ *
+ * @param action One action defined in @key_actions
+ * @return Main/Alt keybinding for the given action
+ */
+int
+key_action_key(int action);
+
 #endif /* __SNGREP_KEYBINDING_H_ */
