@@ -55,6 +55,8 @@ typedef struct setting_option setting_t;
 #define SETTING_ENUM_HIGHLIGHT   (const char *[]){ "bold", "reverse", "reversebold", NULL }
 #define SETTING_ENUM_SDP_INFO    (const char *[]){ "off", "first", "full", "compressed", NULL}
 #define SETTING_ENUM_STORAGE     (const char *[]){ "none", "memory", NULL }
+#define SETTING_ENUM_HEPVERSION  (const char *[]){ "2", "3", NULL }
+#define SETTING_ENUM_MEDIA       (const char *[]){ "on", "off", "rtcp", NULL }
 
 //! Other useful defines
 #define SETTING_ON  "on"
@@ -86,6 +88,7 @@ enum setting_id {
     SETTING_DISPLAY_ALIAS,
     SETTING_CL_SCROLLSTEP,
     SETTING_CL_COLORATTR,
+    SETTING_CL_AUTOSCROLL,
     SETTING_CF_FORCERAW,
     SETTING_CF_RAWMINWIDTH,
     SETTING_CF_RAWFIXEDWIDTH,
@@ -99,10 +102,12 @@ enum setting_id {
     SETTING_CR_SCROLLSTEP,
     SETTING_FILTER_METHODS,
     SETTING_EEP_SEND,
+    SETTING_EEP_SEND_VER,
     SETTING_EEP_SEND_ADDR,
     SETTING_EEP_SEND_PORT,
     SETTING_EEP_SEND_PASS,
     SETTING_EEP_LISTEN,
+    SETTING_EEP_LISTEN_VER,
     SETTING_EEP_LISTEN_ADDR,
     SETTING_EEP_LISTEN_PORT,
     SETTING_EEP_LISTEN_PASS,
@@ -177,6 +182,9 @@ setting_set_intvalue(int id, int value);
 int
 setting_enabled(int id);
 
+int
+setting_disabled(int id);
+
 int
 setting_has_value(int id, const char *value);
 
