@@ -36,6 +36,7 @@
 #include "ui_msg_diff.h"
 #include "util.h"
 #include "vector.h"
+#include "option.h"
 
 /***
  *
@@ -189,7 +190,10 @@ call_flow_draw(PANEL *panel)
             if (!call_flow_draw_message(panel, arrow, cline))
                 break;
         } else if (arrow->type == CF_ARROW_RTP) {
-            if (!call_flow_draw_stream(panel, arrow, cline))
+            if (!call_flow_draw_rtp_stream(panel, arrow, cline))
+                break;
+        } else if (arrow->type == CF_ARROW_RTCP) {
+            if (!call_flow_draw_rtcp_stream(panel, arrow, cline))
                 break;
         }
         cline += arrow->height;
@@ -197,7 +201,18 @@ call_flow_draw(PANEL *panel)
 
     // If there are only three columns, then draw the raw message on this panel
     if (setting_enabled(SETTING_CF_FORCERAW)) {
-        call_flow_draw_raw(panel, call_flow_arrow_message(info->cur_arrow));
+        switch (info->cur_arrow->type) {
+            case CF_ARROW_RTP:
+                call_flow_draw_raw(panel, info->cur_arrow->stream->media->msg);
+                break;
+            case CF_ARROW_SIP:
+                call_flow_draw_raw(panel, info->cur_arrow->msg);
+                break;
+            case CF_ARROW_RTCP:
+                call_flow_draw_raw_rtcp(panel, info->cur_arrow->stream);
+                break;
+        }
+
     }
 
     // Draw the scrollbar
@@ -215,6 +230,19 @@ call_flow_draw(PANEL *panel)
 void
 call_flow_draw_footer(PANEL *panel)
 {
+    call_flow_info_t *info;
+    sip_call_t *call = NULL;
+    WINDOW *win;
+    int streamcnt = 0;
+    int height, width;
+
+    // Get panel information
+    info = call_flow_info(panel);
+
+    // Get window of main panel
+    win = panel_window(panel);
+    getmaxyx(win, height, width);
+
     const char *keybindings[] = {
         key_action_key_str(ACTION_PREV_SCREEN), "Calls List",
         key_action_key_str(ACTION_CONFIRM), "Raw",
@@ -230,6 +258,19 @@ call_flow_draw_footer(PANEL *panel)
     };
 
     draw_keybindings(panel, keybindings, 22);
+
+    // If any dialog has RTP streams and they are not visible
+    if (!setting_enabled(SETTING_CF_MEDIA)) {
+        while ((call = call_group_get_next(info->group, call)) ) {
+            streamcnt += vector_count(call->streams);
+        }
+        // Highlight RTP keybinding
+        if (streamcnt) {
+            wattron(win, A_BOLD | COLOR_PAIR(CP_YELLOW_ON_CYAN));
+            mvwprintw(win, height - 1, 64, "%s %s", key_action_key_str(ACTION_TOGGLE_MEDIA), "RTP");
+            wattroff(win, A_BOLD | COLOR_PAIR(CP_YELLOW_ON_CYAN));
+        }
+    }
 }
 
 int
@@ -267,7 +308,7 @@ call_flow_draw_columns(PANEL *panel)
     }
 
     // Add RTP columns FIXME Really
-    if (setting_enabled(SETTING_CF_MEDIA)) {
+    if (!setting_disabled(SETTING_CF_MEDIA)) {
         while ((call = call_group_get_next(info->group, call)) ) {
             streams = vector_iterator(call->streams);
             while ((stream = vector_iterator_next(&streams))) {
@@ -319,6 +360,7 @@ call_flow_draw_message(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     vector_iter_t medias;
     int color = 0;
     int msglen;
+    int arrow_dir = 0; /* 0: right, 1: left */
 
     // Get panel information
     info = call_flow_info(panel);
@@ -343,27 +385,6 @@ call_flow_draw_message(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     msg_get_attribute(msg, SIP_ATTR_SRC, msg_src);
     msg_get_attribute(msg, SIP_ATTR_DST, msg_dst);
 
-    // Print timestamp
-    if (info->selected == arrow)
-        wattron(win, COLOR_PAIR(CP_CYAN_ON_DEF));
-    mvwprintw(win, cline, 2, "%s", msg_time);
-
-    // Print delta from selected message
-    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
-        if (!info->selected) {
-            if (setting_enabled(SETTING_CF_DELTA))
-                timeval_to_delta(msg_get_time(msg), msg_get_time(call_group_get_next_msg(info->group, msg)), delta);
-        } else if (info->cur_arrow == arrow) {
-            timeval_to_delta(msg_get_time(call_flow_arrow_message(info->selected)), msg_get_time(msg), delta);
-        }
-
-        if (strlen(delta)) {
-            wattron(win, COLOR_PAIR(CP_CYAN_ON_DEF));
-            mvwprintw(win, cline + 1 , 2, "%15s", delta);
-        }
-        wattroff(win, COLOR_PAIR(CP_CYAN_ON_DEF));
-    }
-
     // Get Message method (include extra info)
     sprintf(method, "%s", msg_method);
 
@@ -407,6 +428,7 @@ call_flow_draw_message(PANEL *panel, call_flow_arrow_t *arrow, int cline)
         tmp = column1;
         column1 = column2;
         column2 = tmp;
+        arrow_dir = 1; /* swap arrow direction */
     }
 
     int startpos = 20 + 30 * column1->colpos;
@@ -469,7 +491,7 @@ call_flow_draw_message(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     }
 
     // Write the arrow at the end of the message (two arros if this is a retrans)
-    if (!strcasecmp(msg_src, column1->addr)) {
+    if (arrow_dir == 0 /* right */) {
         mvwaddch(win, cline, endpos - 2, '>');
         if (call_msg_is_retrans(msg)) {
             mvwaddch(win, cline, endpos - 3, '>');
@@ -493,21 +515,45 @@ call_flow_draw_message(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     wattroff(win, COLOR_PAIR(CP_YELLOW_ON_DEF));
     wattroff(win, A_BOLD | A_REVERSE);
 
+    // Print timestamp
+    if (info->selected == arrow)
+        wattron(win, COLOR_PAIR(CP_CYAN_ON_DEF));
+    mvwprintw(win, cline, 2, "%s", msg_time);
+
+    // Print delta from selected message
+    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+        if (!info->selected) {
+            if (setting_enabled(SETTING_CF_DELTA))
+                timeval_to_delta(msg_get_time(call_group_get_prev_msg(info->group, msg)), msg_get_time(msg), delta);
+        } else if (info->cur_arrow == arrow) {
+            timeval_to_delta(msg_get_time(call_flow_arrow_message(info->selected)), msg_get_time(msg), delta);
+        }
+
+        if (strlen(delta)) {
+            wattron(win, COLOR_PAIR(CP_CYAN_ON_DEF));
+            mvwprintw(win, cline - 1 , 2, "%15s", delta);
+        }
+        wattroff(win, COLOR_PAIR(CP_CYAN_ON_DEF));
+    }
+
+    wattroff(win, COLOR_PAIR(CP_CYAN_ON_DEF));
+
     return arrow;
 }
 
 
 call_flow_arrow_t *
-call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
+call_flow_draw_rtp_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
 {
     call_flow_info_t *info;
     WINDOW *win;
-    char codec[50], time[20];
+    char text[50], time[20];
     int height, width;
     const char *callid;
     char msg_dst[80], msg_src[80];
     call_flow_column_t *column1, *column2;
     rtp_stream_t *stream = arrow->stream;
+    int arrow_dir = 0; /* 0: right, 1: left */
 
     // Get panel information
     info = call_flow_info(panel);
@@ -525,23 +571,23 @@ call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     if (cline > height + arrow->height)
         return NULL;
 
-    // Print timestamp
-    timeval_to_time(stream->time, time);
-    mvwprintw(win, cline, 2, "%s", time);
-
     // Get Message method (include extra info)
-    sprintf(codec, "RTP (%s) %d", stream_get_format(stream), stream_get_count(stream));
+    sprintf(text, "RTP (%s) %d", stream_get_format(stream), stream_get_count(stream));
 
     // Get message data
     msg_get_attribute(stream->media->msg, SIP_ATTR_SRC, msg_src);
     msg_get_attribute(stream->media->msg, SIP_ATTR_DST, msg_dst);
+    // Remove port from address. We only look for columns no matter if it matches port or not
+    sip_address_strip_port(msg_src);
+    sip_address_strip_port(msg_dst);
+
     callid = stream->media->msg->call->callid;
 
     // Get origin column for this stream.
     // If we share the same Address from its setup SIP packet, use that column instead.
-    if (!strncmp(stream->ip_src, msg_src, strlen(stream->ip_src))) {
+    if (!strcmp(stream->ip_src, msg_src)) {
         column1 = call_flow_column_get(panel, callid, msg_src);
-    } else if (!strncmp(stream->ip_src, msg_dst, strlen(stream->ip_src))) {
+    } else if (!strcmp(stream->ip_src, msg_dst)) {
         column1 = call_flow_column_get(panel, callid, msg_dst);
     } else {
         column1 = call_flow_column_get(panel, 0, stream->ip_src);
@@ -549,9 +595,9 @@ call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
 
     // Get destination column for this stream.
     // If we share the same Address from its setup SIP packet, use that column instead.
-    if (!strncmp(stream->ip_dst, msg_dst, strlen(stream->ip_dst))) {
+    if (!strcmp(stream->ip_dst, msg_dst)) {
         column2 = call_flow_column_get(panel, callid, msg_dst);
-    } else if (!strncmp(stream->ip_dst, msg_src, strlen(stream->ip_dst))) {
+    } else if (!strcmp(stream->ip_dst, msg_src)) {
         column2 = call_flow_column_get(panel, callid, msg_src);
     } else {
         column2 = call_flow_column_get(panel, 0, stream->ip_dst);
@@ -562,11 +608,20 @@ call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
         tmp = column1;
         column1 = column2;
         column2 = tmp;
+        arrow_dir = 1; /* swap arrow direction */
     }
 
     int startpos = 20 + 30 * column1->colpos;
     int endpos = 20 + 30 * column2->colpos;
-    int distance = abs(endpos - startpos) - 4;
+
+    // In compressed mode, we display the src and dst port inside the arrow
+    // so fixup the stard and end position
+    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+        startpos += 5;
+        endpos -= 5;
+    }
+
+    int distance = abs(endpos - startpos) - 4 + 1;
 
     // Highlight current message
     if (arrow == info->cur_arrow) {
@@ -585,30 +640,31 @@ call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
     // Clear the line
     mvwprintw(win, cline, startpos + 2, "%*s", distance, "");
     // Draw method
-    mvwprintw(win, cline++, startpos + (distance) / 2 - strlen(codec) / 2 + 2, "%s", codec);
+    mvwprintw(win, cline, startpos + (distance) / 2 - strlen(text) / 2 + 2, "%s", text);
+
+    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed"))
+        cline++;
 
     // Draw line between columns
     mvwhline(win, cline, startpos + 2, ACS_HLINE, distance);
-    // Write the arrow at the end of the message (two arros if this is a retrans)
-    if (call_flow_column_get(panel, 0, stream->ip_src) == column1) {
-        mvwprintw(win, cline, startpos - 5, "%d", stream->sport);
-        mvwprintw(win, cline, endpos + 1, "%d", stream->dport);
-        if (distance > 0)
-            mvwaddch(win, cline, endpos - 2, '>');
-        else
-            mvwaddch(win, cline, endpos, '>');
+    // Write the arrow at the end of the message (two arrows if this is a retrans)
+    if (arrow_dir == 0 /* right */) {
+        if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+            mvwprintw(win, cline, startpos - 4, "%d", stream->sport);
+            mvwprintw(win, cline, endpos, "%d", stream->dport);
+        }
+        mvwaddch(win, cline, endpos - 2, '>');
         if (arrow->rtp_count != stream_get_count(stream)) {
             arrow->rtp_count = stream_get_count(stream);
             arrow->rtp_ind_pos = (arrow->rtp_ind_pos + 1) % distance;
             mvwaddch(win, cline, startpos + arrow->rtp_ind_pos + 2, '>');
         }
     } else {
-        mvwprintw(win, cline, endpos  + 1, "%d", stream->sport);
-        mvwprintw(win, cline, startpos - 5, "%d", stream->dport);
-        if (distance > 0)
-            mvwaddch(win, cline, startpos + 2, '<');
-        else
-            mvwaddch(win, cline, startpos, '<');
+        if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+            mvwprintw(win, cline, endpos, "%d", stream->sport);
+            mvwprintw(win, cline, startpos - 4, "%d", stream->dport);
+        }
+        mvwaddch(win, cline, startpos + 2, '<');
         if (arrow->rtp_count != stream_get_count(stream)) {
             arrow->rtp_count = stream_get_count(stream);
             arrow->rtp_ind_pos = (arrow->rtp_ind_pos + 1) % distance;
@@ -616,8 +672,157 @@ call_flow_draw_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
         }
     }
 
+    if (setting_has_value(SETTING_CF_SDP_INFO, "compressed"))
+        mvwprintw(win, cline, startpos + (distance) / 2 - strlen(text) / 2 + 2, " %s ", text);
+
     wattroff(win, A_BOLD | A_REVERSE);
 
+    // Print timestamp
+    timeval_to_time(stream->time, time);
+    mvwprintw(win, cline, 2, "%s", time);
+
+
+    return arrow;
+}
+
+call_flow_arrow_t *
+call_flow_draw_rtcp_stream(PANEL *panel, call_flow_arrow_t *arrow, int cline)
+{
+    call_flow_info_t *info;
+    WINDOW *win;
+    char text[50], time[20];
+    int height, width;
+    const char *callid;
+    char msg_dst[80], msg_src[80];
+    call_flow_column_t *column1, *column2;
+    rtp_stream_t *stream = arrow->stream;
+    int arrow_dir = 0; /* 0: right, 1: left */
+
+    // Get panel information
+    info = call_flow_info(panel);
+    // Get the messages window
+    win = info->flow_win;
+    getmaxyx(win, height, width);
+
+    // Store arrow start line
+    arrow->line = cline;
+
+    // Calculate how many lines this message requires
+    arrow->height = call_flow_arrow_height(panel, arrow);
+
+    // Check this media fits on the panel
+    if (cline > height + arrow->height)
+        return NULL;
+
+    // Arrow text
+    sprintf(text, "RTCP (%.1f) %d", (float) stream->rtcpinfo.mosc / 10, stream_get_count(stream));
+
+    // Get message data
+    msg_get_attribute(stream->media->msg, SIP_ATTR_SRC, msg_src);
+    msg_get_attribute(stream->media->msg, SIP_ATTR_DST, msg_dst);
+    // Remove port from address. We only look for columns no matter if it matches port or not
+    sip_address_strip_port(msg_src);
+    sip_address_strip_port(msg_dst);
+
+    callid = stream->media->msg->call->callid;
+
+    // Get origin column for this stream.
+    // If we share the same Address from its setup SIP packet, use that column instead.
+    if (!strcmp(stream->ip_src, msg_src)) {
+        column1 = call_flow_column_get(panel, callid, msg_src);
+    } else if (!strcmp(stream->ip_src, msg_dst)) {
+        column1 = call_flow_column_get(panel, callid, msg_dst);
+    } else {
+        column1 = call_flow_column_get(panel, 0, stream->ip_src);
+    }
+
+    // Get destination column for this stream.
+    // If we share the same Address from its setup SIP packet, use that column instead.
+    if (!strcmp(stream->ip_dst, msg_dst)) {
+        column2 = call_flow_column_get(panel, callid, msg_dst);
+    } else if (!strcmp(stream->ip_dst, msg_src)) {
+        column2 = call_flow_column_get(panel, callid, msg_src);
+    } else {
+        column2 = call_flow_column_get(panel, 0, stream->ip_dst);
+    }
+
+    call_flow_column_t *tmp;
+    if (column1->colpos > column2->colpos) {
+        tmp = column1;
+        column1 = column2;
+        column2 = tmp;
+        arrow_dir = 1; /* swap arrow direction */
+    }
+
+    int startpos = 20 + 30 * column1->colpos;
+    int endpos = 20 + 30 * column2->colpos;
+
+    // In compressed mode, we display the src and dst port inside the arrow
+    // so fixup the stard and end position
+    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+        startpos += 5;
+        endpos -= 5;
+    }
+
+    int distance = abs(endpos - startpos) - 4 + 1;
+
+    // Highlight current message
+    if (arrow == info->cur_arrow) {
+        if (setting_has_value(SETTING_CF_HIGHTLIGHT, "reverse")) {
+            wattron(win, A_REVERSE);
+        }
+        if (setting_has_value(SETTING_CF_HIGHTLIGHT, "bold")) {
+            wattron(win, A_BOLD);
+        }
+        if (setting_has_value(SETTING_CF_HIGHTLIGHT, "reversebold")) {
+            wattron(win, A_REVERSE);
+            wattron(win, A_BOLD);
+        }
+    }
+
+    // Clear the line
+    mvwprintw(win, cline, startpos + 2, "%*s", distance, "");
+    // Draw method
+    mvwprintw(win, cline, startpos + (distance) / 2 - strlen(text) / 2 + 2, "%s", text);
+    if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed"))
+        cline++;
+
+    // Draw line between columns
+    mvwhline(win, cline, startpos + 2, '-', distance);
+    // Write the arrow at the end of the message (two arrows if this is a retrans)
+    if (arrow_dir == 0 /* right */) {
+        if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+            mvwprintw(win, cline, startpos - 4, "%d", stream->sport);
+            mvwprintw(win, cline, endpos, "%d", stream->dport);
+        }
+        mvwaddch(win, cline, endpos - 2, '>');
+        if (arrow->rtp_count != stream_get_count(stream)) {
+            arrow->rtp_count = stream_get_count(stream);
+            arrow->rtp_ind_pos = (arrow->rtp_ind_pos + 1) % distance;
+            mvwaddch(win, cline, startpos + arrow->rtp_ind_pos + 2, '>');
+        }
+    } else {
+        if (!setting_has_value(SETTING_CF_SDP_INFO, "compressed")) {
+            mvwprintw(win, cline, endpos, "%d", stream->sport);
+            mvwprintw(win, cline, startpos - 4, "%d", stream->dport);
+        }
+        mvwaddch(win, cline, startpos + 2, '<');
+        if (arrow->rtp_count != stream_get_count(stream)) {
+            arrow->rtp_count = stream_get_count(stream);
+            arrow->rtp_ind_pos = (arrow->rtp_ind_pos + 1) % distance;
+            mvwaddch(win, cline, endpos - arrow->rtp_ind_pos - 2, '<');
+        }
+    }
+
+    if (setting_has_value(SETTING_CF_SDP_INFO, "compressed"))
+        mvwprintw(win, cline, startpos + (distance) / 2 - strlen(text) / 2 + 2, " %s ", text);
+
+    wattroff(win, A_BOLD | A_REVERSE);
+
+    // Print timestamp
+    timeval_to_time(stream->time, time);
+    mvwprintw(win, cline, 2, "%s", time);
+
     return arrow;
 }
 
@@ -642,7 +847,7 @@ call_flow_next_arrow(PANEL *panel, const call_flow_arrow_t *cur)
         memset(&cur_time, 0, sizeof(struct timeval));
     } else if (cur->type == CF_ARROW_SIP) {
         cur_time = msg_get_time(cur->msg);
-    } else if (cur->type == CF_ARROW_RTP) {
+    } else if (cur->type == CF_ARROW_RTP || cur->type == CF_ARROW_RTCP) {
         cur_time = cur->stream->time;
     }
 
@@ -653,9 +858,13 @@ call_flow_next_arrow(PANEL *panel, const call_flow_arrow_t *cur)
         }
     }
 
-    if (setting_enabled(SETTING_CF_MEDIA)) {
+    if (!setting_disabled(SETTING_CF_MEDIA)) {
         // Look for the next stream
         while ((stream = call_group_get_next_stream(info->group, stream))) {
+            // Only handle RTCP when required
+            if (!setting_has_value(SETTING_CF_MEDIA, "rtcp") && stream->type == CAPTURE_PACKET_RTCP)
+                continue;
+
             if (timeval_is_older(stream->time, cur_time)) {
                 break;
             }
@@ -669,7 +878,7 @@ call_flow_next_arrow(PANEL *panel, const call_flow_arrow_t *cur)
     if (!msg) {
         // Create a new arrow to store next info
         next = sng_malloc(sizeof(call_flow_arrow_t));
-        next->type = CF_ARROW_RTP;
+        next->type = (stream->type == CAPTURE_PACKET_RTP) ? CF_ARROW_RTP : CF_ARROW_RTCP;
         next->stream = stream;
     } else if (!stream) {
         /* a sip message goes next */
@@ -682,7 +891,7 @@ call_flow_next_arrow(PANEL *panel, const call_flow_arrow_t *cur)
         if (timeval_is_older(msg_get_time(msg), stream->time)) {
             // Create a new arrow to store next info
             next = sng_malloc(sizeof(call_flow_arrow_t));
-            next->type = CF_ARROW_RTP;
+            next->type = (stream->type == CAPTURE_PACKET_RTP) ? CF_ARROW_RTP : CF_ARROW_RTCP;
             next->stream = stream;
         } else {
             // Create a new arrow to store next info
@@ -731,7 +940,9 @@ call_flow_arrow_height(PANEL *panel, const call_flow_arrow_t *arrow)
             return 2;
         if (setting_has_value(SETTING_CF_SDP_INFO, "full"))
             return msg_media_count(arrow->msg) + 2;
-    } else if (arrow->type == CF_ARROW_RTP) {
+    } else if (arrow->type == CF_ARROW_RTP || arrow->type == CF_ARROW_RTCP) {
+        if (setting_has_value(SETTING_CF_SDP_INFO, "compressed"))
+            return 1;
         return 2;
     }
 
@@ -766,7 +977,7 @@ call_flow_arrow_message(const  call_flow_arrow_t *arrow)
         return NULL;
     if (arrow->type == CF_ARROW_SIP)
         return arrow->msg;
-    if (arrow->type == CF_ARROW_RTP)
+    if (arrow->type == CF_ARROW_RTP || arrow->type == CF_ARROW_RTCP)
         return arrow->stream->media->msg;
     return NULL;
 }
@@ -836,6 +1047,78 @@ call_flow_draw_raw(PANEL *panel, sip_msg_t *msg)
     return 0;
 }
 
+
+int
+call_flow_draw_raw_rtcp(PANEL *panel, rtp_stream_t *stream)
+{
+    call_flow_info_t *info;
+    WINDOW *win, *raw_win;
+    int raw_width, raw_height, height, width;
+    int min_raw_width, fixed_raw_width;
+
+    // Get panel information
+    if (!(info = call_flow_info(panel)))
+        return 1;
+
+    // Get window of main panel
+    win = panel_window(panel);
+    getmaxyx(win, height, width);
+
+    // Get min raw width
+    min_raw_width = setting_get_intvalue(SETTING_CF_RAWMINWIDTH);
+    fixed_raw_width = setting_get_intvalue(SETTING_CF_RAWFIXEDWIDTH);
+
+    // Calculate the raw data width (width - used columns for flow - vertical lines)
+    raw_width = width - (30 * vector_count(info->columns)) - 2;
+    // We can define a mininum size for rawminwidth
+    if (raw_width < min_raw_width) {
+        raw_width = min_raw_width;
+    }
+    // We can configure an exact raw size
+    if (fixed_raw_width > 0) {
+        raw_width = fixed_raw_width;
+    }
+
+    // Height of raw window is always available size minus 6 lines for header/footer
+    raw_height = height - 3;
+
+    // If we already have a raw window
+    raw_win = info->raw_win;
+    if (raw_win) {
+        // Check it has the correct size
+        if (getmaxx(raw_win) != raw_width) {
+            // We need a new raw window
+            delwin(raw_win);
+            info->raw_win = raw_win = newwin(raw_height, raw_width, 0, 0);
+        } else {
+            // We have a valid raw win, clear its content
+            werase(raw_win);
+        }
+    } else {
+        // Create the raw window of required size
+        info->raw_win = raw_win = newwin(raw_height, raw_width, 0, 0);
+    }
+
+    // Draw raw box lines
+    wattron(win, COLOR_PAIR(CP_BLUE_ON_DEF));
+    mvwvline(win, 1, width - raw_width - 2, ACS_VLINE, height - 2);
+    wattroff(win, COLOR_PAIR(CP_BLUE_ON_DEF));
+
+    mvwprintw(raw_win, 0, 0, "============ RTCP Information ============");
+    mvwprintw(raw_win, 2, 0, "Sender's packet count: %d", stream->rtcpinfo.spc);
+    mvwprintw(raw_win, 3, 0, "Fraction Lost: %d / 256", stream->rtcpinfo.flost);
+    mvwprintw(raw_win, 4, 0, "Fraction discarded: %d / 256", stream->rtcpinfo.fdiscard);
+    mvwprintw(raw_win, 6, 0, "MOS - Listening Quality: %.1f", (float) stream->rtcpinfo.mosl / 10);
+    mvwprintw(raw_win, 7, 0, "MOS - Conversational Quality: %.1f", (float) stream->rtcpinfo.mosc / 10);
+
+
+
+    // Copy the raw_win contents into the panel
+    copywin(raw_win, win, 0, 0, 1, width - raw_width - 1, raw_height, width - 2, 0);
+
+    return 0;
+}
+
 int
 call_flow_handle_key(PANEL *panel, int key)
 {
@@ -1003,7 +1286,7 @@ call_flow_help(PANEL *panel)
     int height, width;
 
     // Create a new panel and show centered
-    height = 26;
+    height = 27;
     width = 65;
     help_win = newwin(height, width, (LINES - height) / 2, (COLS - width) / 2);
 
@@ -1040,7 +1323,7 @@ call_flow_help(PANEL *panel)
     mvwprintw(help_win, 10, 2, "Enter       Show current message Raw");
     mvwprintw(help_win, 11, 2, "F1/h        Show this screen");
     mvwprintw(help_win, 12, 2, "F2/d        Toggle SDP Address:Port info");
-    mvwprintw(help_win, 13, 2, "F3/t        Toggle raw preview display");
+    mvwprintw(help_win, 13, 2, "F3/m        Toggle RTP arrows display");
     mvwprintw(help_win, 14, 2, "F4/X        Show call-flow with X-CID/X-Call-ID dialog");
     mvwprintw(help_win, 15, 2, "F5/s        Toggle compressed view (One address <=> one column");
     mvwprintw(help_win, 16, 2, "F6/R        Show original call messages in raw mode");
@@ -1048,8 +1331,10 @@ call_flow_help(PANEL *panel)
     mvwprintw(help_win, 18, 2, "F8/C        Turn on/off message syntax highlighting");
     mvwprintw(help_win, 19, 2, "F9/l        Turn on/off resolved addresses");
     mvwprintw(help_win, 20, 2, "9/0         Increase/Decrease raw preview size");
-    mvwprintw(help_win, 21, 2, "T           Restore raw preview size");
-    mvwprintw(help_win, 22, 2, "D           Only show SDP messages");
+    mvwprintw(help_win, 21, 2, "t           Toggle raw preview display");
+    mvwprintw(help_win, 22, 2, "T           Restore raw preview size");
+    mvwprintw(help_win, 23, 2, "D           Only show SDP messages");
+
 
     // Press any key to close
     wgetch(help_win);
@@ -1082,18 +1367,30 @@ call_flow_set_group(sip_call_group_t *group)
 }
 
 void
-call_flow_column_add(PANEL *panel, const char *callid, const char *addr)
+call_flow_column_add(PANEL *panel, const char *callid, const char *address)
 {
     call_flow_info_t *info;
     call_flow_column_t *column;
     vector_iter_t columns;
+    char addr[ADDRESSLEN + 6];
 
     if (!(info = call_flow_info(panel)))
         return;
 
-    if (!addr || !strlen(addr))
+    if (!address || !strlen(address))
         return;
 
+    // Coppy address to local var
+    strcpy(addr, address);
+
+    // when compressed view is enabled
+    if (setting_enabled(SETTING_CF_SPLITCALLID)) {
+        // Remove the port from the address
+        sip_address_strip_port(addr);
+        // Display the alias value of the address
+        strcpy(addr, get_alias_value(addr));
+    }
+
     if (call_flow_column_get(panel, callid, addr))
         return;
 
@@ -1113,18 +1410,30 @@ call_flow_column_add(PANEL *panel, const char *callid, const char *addr)
 }
 
 call_flow_column_t *
-call_flow_column_get(PANEL *panel, const char *callid, const char *addr)
+call_flow_column_get(PANEL *panel, const char *callid, const char *address)
 {
     call_flow_info_t *info;
     call_flow_column_t *column;
     vector_iter_t columns;
     int match_port;
     char coladdr[ADDRESSLEN + 6];
+    char addr[ADDRESSLEN + 6];
     char *dots;
 
     if (!(info = call_flow_info(panel)))
         return NULL;
 
+    // Coppy address to local var
+    strcpy(addr, address);
+
+    // when compressed view is enabled
+    if (setting_enabled(SETTING_CF_SPLITCALLID)) {
+        // Remove the port from the address
+        sip_address_strip_port(addr);
+        // Display the alias value of the address
+        strcpy(addr, get_alias_value(addr));
+    }
+
     // Look for address or address:port ?
     match_port = (strchr(addr, ':') != NULL);
 
