@@ -115,6 +115,9 @@ call_list_create()
     vector_iterator_set_filter(&info->calls, filter_check_call);
     info->cur_call = info->first_call = -1;
 
+    // Set autoscroll default status
+    info->autoscroll = setting_enabled(SETTING_CL_AUTOSCROLL);
+
     // Return the created panel
     return panel;
 }
@@ -215,6 +218,9 @@ call_list_draw_header(PANEL *panel)
         mvwprintw(win, 3, colpos, "%.*s", collen, coldesc);
         colpos += collen + 1;
     }
+    // Print Autoscroll indicator
+    if (info->autoscroll)
+        mvwprintw(win, 3, 0, "A");
     wattroff(win, A_BOLD | A_REVERSE | COLOR_PAIR(CP_DEF_ON_CYAN));
 
     // Get filter call counters
@@ -227,6 +233,7 @@ call_list_draw_header(PANEL *panel)
     } else {
         mvwprintw(win, 1, 35, "Dialogs: %d", info->callcnt);
     }
+
 }
 
 void
@@ -268,6 +275,11 @@ call_list_draw_list(PANEL *panel)
     win = info->list_win;
     getmaxyx(win, height, width);
 
+    // If autoscroll is enabled, select the last dialog
+    if (info->autoscroll) {
+        call_list_handle_key(panel, key_action_key(ACTION_END));
+    }
+
     // If no active call, use the fist one (if exists)
     if (info->first_call == -1 && vector_iterator_count(&info->calls)) {
         vector_iterator_reset(&info->calls);
@@ -292,17 +304,17 @@ call_list_draw_list(PANEL *panel)
         if (!call_msg_count(call))
             continue;
 
-        // Reverse colors on monochrome terminals
-        if (!has_colors())
-            wattron(win, A_REVERSE);
-
         // Show bold selected rows
         if (call_group_exists(info->group, call))
             wattron(win, A_BOLD | COLOR_PAIR(CP_DEFAULT));
 
         // Highlight active call
-        if (call->index == info->cur_call + 1)
-            wattron(win, COLOR_PAIR(CP_DEF_ON_BLUE));
+        if (call->index == info->cur_call + 1) {
+            wattron(win, COLOR_PAIR(CP_WHITE_ON_BLUE));
+            // Reverse colors on monochrome terminals
+            if (!has_colors())
+                wattron(win, A_REVERSE);
+        }
         // Set current line background
         clear_line(win, cline);
         // Set current line selection box
@@ -493,6 +505,8 @@ call_list_handle_key(PANEL *panel, int key)
                     info->first_line++;
                     info->cur_line = height;
                 }
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_UP:
                 // Check if there is a call above us
@@ -507,6 +521,8 @@ call_list_handle_key(PANEL *panel, int key)
                     info->first_line--;
                     info->cur_line = 1;
                 }
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_HNPAGE:
                 rnpag_steps = rnpag_steps / 2;
@@ -515,6 +531,8 @@ call_list_handle_key(PANEL *panel, int key)
                 // Next page => N key down strokes
                 for (i = 0; i < rnpag_steps; i++)
                     call_list_handle_key(panel, KEY_DOWN);
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_HPPAGE:
                 rnpag_steps = rnpag_steps / 2;
@@ -523,11 +541,15 @@ call_list_handle_key(PANEL *panel, int key)
                 // Prev page => N key up strokes
                 for (i = 0; i < rnpag_steps; i++)
                     call_list_handle_key(panel, KEY_UP);
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_BEGIN:
                 // Initialize structures
                 info->first_call = info->cur_call = -1;
                 info->first_line = info->cur_line = 0;
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_END:
                 // Check if there is a call below us
@@ -549,6 +571,8 @@ call_list_handle_key(PANEL *panel, int key)
             case ACTION_DISP_FILTER:
                 // Activate Form
                 call_list_form_activate(panel, 1);
+                // Disable Autoscroll
+                info->autoscroll = 0;
                 break;
             case ACTION_SHOW_FLOW:
             case ACTION_SHOW_FLOW_EX:
@@ -582,17 +606,13 @@ call_list_handle_key(PANEL *panel, int key)
             case ACTION_SHOW_COLUMNS:
                 ui_create_panel(PANEL_COLUMN_SELECT);
                 break;
+            case ACTION_SHOW_STATS:
+                ui_create_panel(PANEL_STATS);
+                break;
             case ACTION_SAVE:
                 next_panel = ui_create_panel(PANEL_SAVE);
                 save_set_group(ui_get_panel(next_panel), info->group);
                 break;
-            case ACTION_DISP_INVITE:
-                // Set Display filter text
-                set_field_buffer(info->fields[FLD_LIST_FILTER], 0, "invite");
-                filter_set(FILTER_CALL_LIST, "invite");
-                call_list_clear(panel);
-                filter_reset_calls();
-                break;
             case ACTION_CLEAR:
                 // Clear group calls
                 vector_clear(info->group->calls);
@@ -603,6 +623,9 @@ call_list_handle_key(PANEL *panel, int key)
                 // Clear List
                 call_list_clear(panel);
                 break;
+            case ACTION_AUTOSCROLL:
+                info->autoscroll = (info->autoscroll) ? 0 : 1;
+                break;
             case ACTION_SHOW_SETTINGS:
                 ui_create_panel(PANEL_SETTINGS);
                 break;
