@@ -56,7 +56,7 @@ filter_create()
     const char *method;
 
     // Calculate window dimensions
-    height = 15;
+    height = 16;
     width = 50;
 
     // Cerate a new indow for the panel and form
@@ -76,13 +76,14 @@ filter_create()
     info->fields[FLD_FILTER_SIPTO] = new_field(1, 28, 4, 18, 0, 0);
     info->fields[FLD_FILTER_SRC] = new_field(1, 18, 5, 18, 0, 0);
     info->fields[FLD_FILTER_DST] = new_field(1, 18, 6, 18, 0, 0);
-    info->fields[FLD_FILTER_REGISTER] = new_field(1, 1, 8, 15, 0, 0);
-    info->fields[FLD_FILTER_INVITE] = new_field(1, 1, 9, 15, 0, 0);
-    info->fields[FLD_FILTER_SUBSCRIBE] = new_field(1, 1, 10, 15, 0, 0);
-    info->fields[FLD_FILTER_NOTIFY] = new_field(1, 1, 11, 15, 0, 0);
-    info->fields[FLD_FILTER_OPTIONS] = new_field(1, 1, 8, 37, 0, 0);
-    info->fields[FLD_FILTER_PUBLISH] = new_field(1, 1, 9, 37, 0, 0);
-    info->fields[FLD_FILTER_MESSAGE] = new_field(1, 1, 10, 37, 0, 0);
+    info->fields[FLD_FILTER_PAYLOAD] = new_field(1, 28, 7, 18, 0, 0);
+    info->fields[FLD_FILTER_REGISTER] = new_field(1, 1, 9, 15, 0, 0);
+    info->fields[FLD_FILTER_INVITE] = new_field(1, 1, 10, 15, 0, 0);
+    info->fields[FLD_FILTER_SUBSCRIBE] = new_field(1, 1, 11, 15, 0, 0);
+    info->fields[FLD_FILTER_NOTIFY] = new_field(1, 1, 12, 15, 0, 0);
+    info->fields[FLD_FILTER_OPTIONS] = new_field(1, 1, 9, 37, 0, 0);
+    info->fields[FLD_FILTER_PUBLISH] = new_field(1, 1, 10, 37, 0, 0);
+    info->fields[FLD_FILTER_MESSAGE] = new_field(1, 1, 11, 37, 0, 0);
     info->fields[FLD_FILTER_FILTER] = new_field(1, 10, height - 2, 11, 0, 0);
     info->fields[FLD_FILTER_CANCEL] = new_field(1, 10, height - 2, 30, 0, 0);
     info->fields[FLD_FILTER_COUNT] = NULL;
@@ -92,6 +93,7 @@ filter_create()
     field_opts_off(info->fields[FLD_FILTER_SIPTO], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_SRC], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_DST], O_AUTOSKIP);
+    field_opts_off(info->fields[FLD_FILTER_PAYLOAD], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_REGISTER], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_INVITE], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_SUBSCRIBE], O_AUTOSKIP);
@@ -107,6 +109,7 @@ filter_create()
     set_field_back(info->fields[FLD_FILTER_SIPTO], A_UNDERLINE);
     set_field_back(info->fields[FLD_FILTER_SRC], A_UNDERLINE);
     set_field_back(info->fields[FLD_FILTER_DST], A_UNDERLINE);
+    set_field_back(info->fields[FLD_FILTER_PAYLOAD], A_UNDERLINE);
 
     // Create the form and post it
     info->form = new_form(info->fields);
@@ -118,13 +121,14 @@ filter_create()
     mvwprintw(win, 4, 3, "SIP To:");
     mvwprintw(win, 5, 3, "Source:");
     mvwprintw(win, 6, 3, "Destination:");
-    mvwprintw(win, 8, 3, "REGISTER   [ ]");
-    mvwprintw(win, 9, 3, "INVITE     [ ]");
-    mvwprintw(win, 10, 3, "SUBSCRIBE  [ ]");
-    mvwprintw(win, 11, 3, "NOTIFY     [ ]");
-    mvwprintw(win, 8, 25, "OPTIONS    [ ]");
-    mvwprintw(win, 9, 25, "PUBLISH    [ ]");
-    mvwprintw(win, 10, 25, "MESSAGE    [ ]");
+    mvwprintw(win, 7, 3, "Payload:");
+    mvwprintw(win, 9, 3, "REGISTER   [ ]");
+    mvwprintw(win, 10, 3, "INVITE     [ ]");
+    mvwprintw(win, 11, 3, "SUBSCRIBE  [ ]");
+    mvwprintw(win, 12, 3, "NOTIFY     [ ]");
+    mvwprintw(win, 9, 25, "OPTIONS    [ ]");
+    mvwprintw(win, 10, 25, "PUBLISH    [ ]");
+    mvwprintw(win, 11, 25, "MESSAGE    [ ]");
 
     // Get Method filter
     if (!(method = filter_get(FILTER_METHOD)))
@@ -135,6 +139,7 @@ filter_create()
     set_field_buffer(info->fields[FLD_FILTER_SIPTO], 0, filter_get(FILTER_SIPTO));
     set_field_buffer(info->fields[FLD_FILTER_SRC], 0, filter_get(FILTER_SOURCE));
     set_field_buffer(info->fields[FLD_FILTER_DST], 0, filter_get(FILTER_DESTINATION));
+    set_field_buffer(info->fields[FLD_FILTER_PAYLOAD], 0, filter_get(FILTER_PAYLOAD));
     set_field_buffer(info->fields[FLD_FILTER_REGISTER], 0,
                      strstr(method, sip_method_str(SIP_METHOD_REGISTER)) ? "*" : "");
     set_field_buffer(info->fields[FLD_FILTER_INVITE], 0,
@@ -156,9 +161,9 @@ filter_create()
     mvwprintw(win, 1, 18, "Filter options");
     wattron(win, COLOR_PAIR(CP_BLUE_ON_DEF));
     title_foot_box(panel);
-    mvwhline(win, 7, 1, ACS_HLINE, 49);
-    mvwaddch(win, 7, 0, ACS_LTEE);
-    mvwaddch(win, 7, 49, ACS_RTEE);
+    mvwhline(win, 8, 1, ACS_HLINE, 49);
+    mvwaddch(win, 8, 0, ACS_LTEE);
+    mvwaddch(win, 8, 49, ACS_RTEE);
     wattroff(win, COLOR_PAIR(CP_BLUE_ON_DEF));
 
     // Set default cursor position
@@ -199,7 +204,8 @@ filter_handle_key(PANEL *panel, int key)
     // We trim spaces with sscanf because and empty field is stored as
     // space characters
     memset(field_value, 0, sizeof(field_value));
-    sscanf(field_buffer(current_field(info->form), 0), "%[^ ]", field_value);
+    strcpy(field_value, field_buffer(current_field(info->form), 0));
+    strtrim(field_value);
 
     // Check actions for this key
     while ((action = key_find_action(key, action)) != ERR) {
@@ -208,7 +214,8 @@ filter_handle_key(PANEL *panel, int key)
             case ACTION_PRINTABLE:
                 // If this is a normal character on input field, print it
                 if (field_idx == FLD_FILTER_SIPFROM || field_idx == FLD_FILTER_SIPTO
-                    || field_idx == FLD_FILTER_SRC || field_idx == FLD_FILTER_DST) {
+                    || field_idx == FLD_FILTER_SRC || field_idx == FLD_FILTER_DST
+                    || field_idx == FLD_FILTER_PAYLOAD) {
                     form_driver(info->form, key);
                     break;
                 }
@@ -319,7 +326,8 @@ filter_save_options(PANEL *panel)
         // We trim spaces with sscanf because and empty field is stored as
         // space characters
         memset(field_value, 0, sizeof(field_value));
-        sscanf(field_buffer(info->fields[field_id], 0), "%[^ ]", field_value);
+        strcpy(field_value, field_buffer(info->fields[field_id], 0));
+        strtrim(field_value);
 
         // Set filter expression
         expr = strlen(field_value) ? field_value : NULL;
@@ -337,6 +345,9 @@ filter_save_options(PANEL *panel)
             case FLD_FILTER_DST:
                 filter_set(FILTER_DESTINATION, expr);
                 break;
+            case FLD_FILTER_PAYLOAD:
+                filter_set(FILTER_PAYLOAD, expr);
+                break;
             case FLD_FILTER_REGISTER:
             case FLD_FILTER_INVITE:
             case FLD_FILTER_SUBSCRIBE:
