@@ -59,7 +59,8 @@ static ui_t *panel_pool[] = {
     &ui_save,
     &ui_msg_diff,
     &ui_column_select,
-    &ui_settings
+    &ui_settings,
+    &ui_stats
 };
 
 int
@@ -128,8 +129,10 @@ ncurses_init()
     init_pair(CP_WHITE_ON_DEF, COLOR_WHITE, bg);
     init_pair(CP_DEF_ON_CYAN, fg, COLOR_CYAN);
     init_pair(CP_DEF_ON_BLUE, fg, COLOR_BLUE);
+    init_pair(CP_WHITE_ON_BLUE, COLOR_WHITE, COLOR_BLUE);
     init_pair(CP_BLACK_ON_CYAN, COLOR_BLACK, COLOR_CYAN);
     init_pair(CP_WHITE_ON_CYAN, COLOR_WHITE, COLOR_CYAN);
+    init_pair(CP_YELLOW_ON_CYAN, COLOR_YELLOW, COLOR_CYAN);
     init_pair(CP_BLUE_ON_CYAN, COLOR_BLUE, COLOR_CYAN);
     init_pair(CP_BLUE_ON_WHITE, COLOR_BLUE, COLOR_WHITE);
     init_pair(CP_CYAN_ON_WHITE, COLOR_CYAN, COLOR_WHITE);
