@@ -74,8 +74,7 @@ save_create()
     panel = new_panel(win);
 
     // Initialize save panel specific data
-    info = malloc(sizeof(save_info_t));
-    memset(info, 0, sizeof(save_info_t));
+    info = sng_malloc(sizeof(save_info_t));
 
     // Store it into panel userptr
     set_panel_userptr(panel, (void*) info);
@@ -104,6 +103,10 @@ save_create()
     set_field_back(info->fields[FLD_SAVE_PATH], A_UNDERLINE);
     set_field_back(info->fields[FLD_SAVE_FILE], A_UNDERLINE);
 
+    // Disable Save RTP if RTP packets are not being captured
+    if (!setting_enabled(SETTING_CAPTURE_RTP))
+        field_opts_off(info->fields[FLD_SAVE_PCAP_RTP], O_ACTIVE);
+
     // Create the form and post it
     info->form = new_form(info->fields);
     set_form_sub(info->form, win);
@@ -120,7 +123,7 @@ save_create()
     // Set window boxes
     wattron(win, COLOR_PAIR(CP_BLUE_ON_DEF));
     // Window border
-    title_foot_box(panel_window(panel));
+    title_foot_box(panel);
 
     // Header and footer lines
     mvwhline(win, height - 3, 1, ACS_HLINE, width - 1);
@@ -189,7 +192,7 @@ save_destroy(PANEL *panel)
 
         // Remove panel window and custom info
         delwin(panel_window(panel));
-        free(info);
+        sng_free(info);
     }
 
     // Resume capture
@@ -252,6 +255,10 @@ save_draw(PANEL *panel)
     set_field_buffer(info->fields[FLD_SAVE_PCAP_RTP], 0, (info->saveformat == SAVE_PCAP_RTP) ? "*" : " ");
     set_field_buffer(info->fields[FLD_SAVE_TXT], 0, (info->saveformat == SAVE_TXT) ? "*" : " ");
 
+    // Show disabled options with makers
+    if (!setting_enabled(SETTING_CAPTURE_RTP))
+        set_field_buffer(info->fields[FLD_SAVE_PCAP_RTP], 0, "-");
+
     set_current_field(info->form, current_field(info->form));
     form_driver(info->form, REQ_VALIDATION);
 
@@ -428,8 +435,8 @@ save_to_file(PANEL *panel)
     sprintf(fullfile, "%s%s", savepath, savefile);
 
     if (access(fullfile, R_OK) == 0) {
-        dialog_run("Error: file %s already exists.", fullfile);
-        return 1;
+        if (dialog_confirm("Overwrite confirmation", "Selected file already exits.\n Do you want to overwrite it?", "Yes,No") != 0)
+            return 1;
     }
 
     // Don't allow to save no packets!
@@ -500,13 +507,9 @@ save_to_file(PANEL *panel)
             msgs = vector_iterator(call->msgs);
             // Save SIP message content
             while ((msg = vector_iterator_next(&msgs))) {
-                capture_packet_t *packet;
-                vector_iter_t it = vector_iterator(msg->packets);
-                while ((packet = vector_iterator_next(&it))) {
-                    // Update progress bar dialog
-                    dialog_progress_set_value(progress, (++cur * 100) / total);
-                    vector_append(sorted, packet);
-                }
+                // Update progress bar dialog
+                dialog_progress_set_value(progress, (++cur * 100) / total);
+                vector_append(sorted, msg->packet);
             }
 
             // Save RTP packets
@@ -523,7 +526,7 @@ save_to_file(PANEL *panel)
         // Save sorted packets
         packets = vector_iterator(sorted);
         while ((packet = vector_iterator_next(&packets))) {
-            save_packet_pcap(pd, packet);
+            dump_packet(pd, packet);
         }
 
         dialog_progress_destroy(progress);
@@ -542,17 +545,15 @@ save_to_file(PANEL *panel)
     return 27;
 }
 
-void
-save_packet_pcap(pcap_dumper_t *pd, capture_packet_t *packet)
-{
-    dump_packet(pd, packet->header, packet->data);
-}
-
-
 void
 save_msg_txt(FILE *f, sip_msg_t *msg)
 {
-    fprintf(f, "%s %s %s -> %s\n%s\n\n", msg_get_attribute(msg, SIP_ATTR_DATE),
-            msg_get_attribute(msg, SIP_ATTR_TIME), msg_get_attribute(msg, SIP_ATTR_SRC),
-            msg_get_attribute(msg, SIP_ATTR_DST), msg_get_payload(msg));
+    char date[20], time[20], src[80], dst[80];
+
+    fprintf(f, "%s %s %s -> %s\n%s\n\n",
+            msg_get_attribute(msg, SIP_ATTR_DATE, date),
+            msg_get_attribute(msg, SIP_ATTR_TIME, time),
+            msg_get_attribute(msg, SIP_ATTR_SRC, src),
+            msg_get_attribute(msg, SIP_ATTR_DST, dst),
+            msg_get_payload(msg));
 }
