@@ -78,10 +78,12 @@ settings_entry_t entries[] = {
     { CAT_SETTINGS_CALL_FLOW,  FLD_SETTINGS_CF_MEDIA,           SETTING_CF_MEDIA,           "Show RTP media streams ...................." },
     { CAT_SETTINGS_CALL_FLOW,  FLD_SETTINGS_CF_SCROLLSTEP,      SETTING_CF_SCROLLSTEP,      "Steps for PgUp/PgDown ....................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_SEND,           SETTING_EEP_SEND,           "Send all captured SIP packets ............." },
+    { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_SEND_VER,       SETTING_EEP_SEND_VER,       "Send EEP version .........................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_SEND_ADDR,      SETTING_EEP_SEND_ADDR,      "Send EEP packet address ..................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_SEND_PORT,      SETTING_EEP_SEND_PORT,      "Send EEP packet port ......................" },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_SEND_PASS,      SETTING_EEP_SEND_PASS,      "EEP send password ........................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_LISTEN,         SETTING_EEP_LISTEN,         "Listen for eep packets ...................." },
+    { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_LISTEN_VER,     SETTING_EEP_LISTEN_VER,     "Listen EEP version  ......................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_LISTEN_ADDR,    SETTING_EEP_LISTEN_ADDR,    "Listen EEP packet address ................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_LISTEN_PORT,    SETTING_EEP_LISTEN_PORT,    "Listen EEP packet port ...................." },
     { CAT_SETTINGS_EEP_HOMER,  FLD_SETTINGS_EEP_LISTEN_PASS,    SETTING_EEP_LISTEN_PASS,    "EEP server password ......................." },
@@ -447,7 +449,8 @@ ui_settings_update_settings(PANEL *panel)
         if ((entry = ui_settings_is_entry(info->fields[i]))) {
             // Get field value.
             memset(field_value, 0, sizeof(field_value));
-            sscanf(field_buffer(info->fields[i], 0), "%[^ ]", field_value);
+            strcpy(field_value, field_buffer(info->fields[i], 0));
+            strtrim(field_value);
             // Change setting value
             setting_set_value(entry->setting_id, field_value);
         }
@@ -508,7 +511,8 @@ ui_settings_save(PANEL *panel)
         if ((entry = ui_settings_is_entry(info->fields[i]))) {
             // Get field value.
             memset(field_value, 0, sizeof(field_value));
-            sscanf(field_buffer(info->fields[i], 0), "%[^ ]", field_value);
+            strcpy(field_value, field_buffer(info->fields[i], 0));
+            strtrim(field_value);
 
             // Change setting value
             fprintf(fo, "set %s %s\n", setting_name(entry->setting_id), field_value);
