@@ -35,6 +35,42 @@
 #include "util.h"
 
 
+void *
+sng_malloc(size_t size)
+{
+    void *data;
+
+    // Check memory allocation size
+    if (size <= 0 || size > MALLOC_MAX_SIZE)
+        return NULL;
+
+    // Allocate memory
+    if (!(data = malloc(size)))
+        return NULL;
+
+    // Initialize allocated memory
+    memset(data, 0, size);
+    return data;
+}
+
+void
+sng_free(void *ptr)
+{
+    if (ptr)
+        free(ptr);
+}
+
+int
+timeval_is_older(struct timeval t1, struct timeval t2)
+{
+    long long int t1sec, t2sec;
+    t1sec = t1.tv_sec;
+    t1sec = t1sec * 1000000;
+    t2sec = t2.tv_sec;
+    t2sec = t2sec * 1000000;
+    return ((t2sec + t2.tv_usec) - (t1sec + t1.tv_usec) < 0);
+}
+
 const char *
 timeval_to_date(struct timeval time, char *out)
 {
