@@ -32,6 +32,32 @@
 // Capture headers has some fixes for pcap timevals in BSD systems
 #include "capture.h"
 
+// Max Memmory allocation
+#define MALLOC_MAX_SIZE 102400
+
+
+/**
+ * @brief Wrapper for memory allocation
+ */
+void *
+sng_malloc(size_t size);
+
+/**
+ * @brief Wrapper for memmory deallocation
+ */
+void
+sng_free(void *ptr);
+
+/**
+ * @brief Compare two timeval structures
+ *
+ * @param t1 First timeval structure
+ * @param t2 Second timval structure
+ * @return 1 if t1 > t2, 0 if t1 <= t2
+ */
+int
+timeval_is_older(struct timeval t1, struct timeval t2);
+
 /**
  * @brief Convert timeval to yyyy/mm/dd format
  */
