@@ -249,6 +249,12 @@ vector_iterator_set_filter(vector_iter_t *it, int (*filter) (void *item));
 void
 vector_iterator_set_current(vector_iter_t *it, int current);
 
+/**
+ * @brief Set iterator position to the last element
+ */
+void
+vector_iterator_set_last(vector_iter_t *it);
+
 /**
  * @brief Return current iterator position
  */
